.. DO NOT EDIT THIS FILE BY HAND, EDIT sphinx/source/conf.py FILE INSTEAD

![OMAS version](https://img.shields.io/github/tag-date/gafusion/omas.svg?label=version&color=blue)
![GitHub repo size](https://img.shields.io/github/repo-size/gafusion/omas.svg?color=blue)
![IMAS version](https://img.shields.io/badge/IMAS-3.25.0-yellow)

[![Build Status](https://travis-ci.org/gafusion/omas.svg?branch=master)](https://travis-ci.org/gafusion/omas)
[![Codecov](https://codecov.io/gh/gafusion/omas/branch/master/graph/badge.svg)](https://codecov.io/gh/gafusion/omas)

# **OMAS** (**O**rdered **M**ultidimensional **A**rray **S**tructure)

OMAS is a Python library designed to simplify the interface of third-party codes with the [ITER](http://iter.org) Integrated Modeling and Analysis Suite ([IMAS](https://confluence.iter.org/display/IMP)).

* It provides a **convenient Python API**

* capable of storing data with **different file/database formats**

* in a form that is **always compatible with the IMAS data model**

Mapping the physics codes I/O to the IMAS data model is done in third party Python codes such as the [OMFIT framework](http://gafusion.github.io/OMFIT-source).

For more info, visit: https://gafusion.github.io/omas
